SystemOrganization addCategory: #GODSpreadsheetTests!

TestCase subclass: #GODSpreadsheetDataTest
	instanceVariableNames: 'godSSData'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODSpreadsheetTests'!

!GODSpreadsheetDataTest methodsFor: 'initializing' stamp: 'dhk 10/26/2014 15:25'!
setUp

	godSSData := SSSpreadsheetData new initialize.
	godSSData createSheetWithName: 'sheet1';
		createSheetWithName: 'sheet2';
		createSheetWithName: 'sheet3'.! !

!GODSpreadsheetDataTest methodsFor: 'testing' stamp: 'dhk 10/2/2014 21:39'!
testChangeName
	|sheet|
	sheet := godSSData getSheetWithName: 'sheet3'.
	godSSData renameSheet: 'sheet3' toName: 'super sheet'.
	self assert: (sheet name) = 'super sheet'.
	self assert: (godSSData getSheetWithName: 'super sheet') notNil.! !

!GODSpreadsheetDataTest methodsFor: 'testing' stamp: 'dhk 10/2/2014 21:33'!
testCreateSheet
	|tempGodSSData|

	tempGodSSData := SSSpreadsheetData new.

	tempGodSSData createSheetWithName: 'teste'.

	self assert: (tempGodSSData numberOfSheets) = 1.

	self assert: (tempGodSSData getSheet: 1) notNil.
	self assert: (tempGodSSData getSheetWithName: 'teste') notNil.! !

!GODSpreadsheetDataTest methodsFor: 'testing' stamp: 'dhk 10/17/2014 16:04'!
testParseCSV
	|csvfilecontent spreadsheet|

	csvfilecontent := (FileStream fileNamed: 'alo.csv') contents.
	spreadsheet := SSSpreadsheetData fromFile: 'alo.csv'.
	
	self assert: (csvfilecontent) notNil.! !

!GODSpreadsheetDataTest methodsFor: 'testing' stamp: 'foa 9/27/2014 18:38'!
testSheetsOrder
	|sheet1 sheet2|

	sheet1 := godSSData getSheet: 1.
	sheet2 := godSSData getSheetWithName: 'sheet1'.
	self assert: sheet1 == sheet2.

	sheet1 := godSSData getSheet: 2.
	sheet2 := godSSData getSheetWithName: 'sheet2'.

	self assert: sheet1 == sheet2.! !

TestCase subclass: #SSCellTest
	instanceVariableNames: 'ssCell'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODSpreadsheetTests'!

!SSCellTest methodsFor: 'testing' stamp: 'dhk 10/2/2014 21:40'!
testCellCreation
	|cell|

	cell := SSCell new.
	cell value: 'alo alo'.
	self assert: (cell value) = 'alo alo'! !

!SSCellTest methodsFor: 'testing' stamp: 'dhk 10/29/2014 21:51'!
testCellCreation2
	|sheet cell|

	sheet := SSSheet new: 'sheet1'.
	cell := sheet createCellAtRow: 2 atColumn: 'A' withValue: 'alo alo'.
	self assert: (cell value) = 'alo alo'.
	self assert: (cell column) = 'A'.
	self assert: (cell getRowIndex) = 2.
	self assert: (cell parent) == (sheet getRow: 2).
	self assert: (cell getColumnIndex) = 1.! !

!SSCellTest methodsFor: 'testing' stamp: 'dhk 10/29/2014 21:51'!
testCellParent
	|sheet row cell|

	sheet := SSSheet new: 'sheet1'.
	cell := sheet createCellAtRow: 2 atColumn: 'A' withValue: 'alo alo'.
	row := sheet getRow: 2.
	self assert: (cell parent) == row.
	self assert: (cell getParentRow) == row.! !

TestCase subclass: #SSRowTest
	instanceVariableNames: 'row sheet'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODSpreadsheetTests'!

!SSRowTest methodsFor: 'initializing' stamp: 'dhk 10/29/2014 18:09'!
setUp

	sheet := SSSheet new: 'sheet1'.
	row := sheet createRowAtIndex: 2.! !

!SSRowTest methodsFor: 'testing' stamp: 'dhk 10/17/2014 19:36'!
testCellOperations
	|cell1 cell2 cell3|
	cell1 := SSCell new.
	cell2 := SSCell new.
	cell3 := SSCell new.
	row addCell: cell1 atColumn: 'A'.
	row addCell: cell2 atColumnIndex: 2.
	row addCell: cell3 atColumn: 'C'.
	
	self assert: (row getCell: 'A') == cell1.
	self assert: (row getCellAtIndex: 2) == cell2.
	self assert: (row getCell: 'C') notNil.

	row deleteCell: 'C'.
	row deleteCellAtIndex: 2.

	self should: [row getCell: 'C'] raise: Error.
	self should: [row getCellAtIndex: 2] raise: Error.! !

!SSRowTest methodsFor: 'testing' stamp: 'dhk 10/17/2014 18:33'!
testOneColumn
	|cell1|
	cell1 := SSCell new.
	row addCell: cell1 atColumnIndex: 1.
	
	self assert: (row getCellAtIndex: 1) == cell1.! !

!SSRowTest methodsFor: 'testing' stamp: 'dhk 10/29/2014 18:10'!
testRowIndex

	self assert: (row index) = 2.! !

!SSRowTest methodsFor: 'testing' stamp: 'dhk 10/29/2014 18:09'!
testRowParent

	self assert: (row parent) = sheet.! !

TestCase subclass: #SSSheetTest
	instanceVariableNames: 'sheet'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODSpreadsheetTests'!

!SSSheetTest methodsFor: 'initializing' stamp: 'foa 9/27/2014 18:29'!
setUp

	sheet := SSSheet new: 'sheet1'.! !

!SSSheetTest methodsFor: 'testing' stamp: 'dhk 10/29/2014 22:17'!
testALot 

	| ssData sheet cell |
	ssData := SSSpreadsheetData new.
	sheet := ssData createSheetWithName: 'zubat'.
	cell := sheet createCellAtRow: 1 atColumn: 'A' withValue: 32.
	self assert: (sheet getCellAtRow: 1 atColumn: 'A') == cell.
	self assert: (sheet getCellAtRow: 1 atColumnIndex: 1) == cell.
	
	cell := sheet createCellAtRow: 4 atColumnIndex: 4 withValue: 42.
	self assert: (sheet getCellAtRow: 4 atColumn: 'D') == cell.
	self assert: (sheet getCellAtRow: 4 atColumnIndex: 4) == cell.
	
	self assert: (sheet index) = 1.! !

!SSSheetTest methodsFor: 'testing' stamp: 'dhk 10/2/2014 21:39'!
testName

	self assert: (sheet name) = 'sheet1'.

	sheet changeName: 'sheet2'.
	self assert: (sheet name) = 'sheet2'.! !

!SSSheetTest methodsFor: 'testing' stamp: 'dhk 10/29/2014 21:55'!
testParent

	| ssData sheet |
	ssData := SSSpreadsheetData new.
	sheet := ssData createSheetWithName: 'zubat'.
	self assert: (sheet parent) = ssData.! !

!SSSheetTest methodsFor: 'testing' stamp: 'dhk 10/17/2014 19:34'!
testRowOperations

	| row1 row2 cell1 cell2 |

	row1 := sheet createRow.
	row2 := sheet createRowAtIndex: 3.

	self assert: (sheet getRow: 1) == row1.
	self assert: (sheet getRow: 3) == row2.

	sheet deleteRow: 3. 
	self should: [sheet getRow: 3] raise: Error.

	cell1 := SSCell new.
	cell2 := SSCell new.

	row1 addCell: cell1 atColumn: 'A';
		   addCell: cell2 atColumn: 'B'.

	self assert: (sheet getCellAtRow: 1 atColumn: 'A') == cell1.
	self assert: (sheet getCellAtRow: 1 atColumnIndex: 2) == cell2.! !
